<!-- PROJECT SHIELDS -->
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]

<!-- PROJECT LOGO -->
<p align="center">
  <a>
    <img src="logo/ai_grams_camel.png" alt="Logo" width="280" height="300">
  </a>

  <h1 align="center">AI Grams PM Project</h3>

  <p align="center">
    <a href="https://aigrams.github.io/ai_grams_pm/"><strong>Explore the docs »</strong></a>
  </p>
</p>

<!-- ABOUT THE PROJECT -->
## About The Project
This package belongs to AI Grams, an Italian startup working in the field of European power markets. 

<!-- GETTING STARTED -->
## Getting Started
In order to install ai_grams_pm package, please digit:

```sh
pip3 install ai_grams_pm
```

<!-- CONTACT -->
## Contact
AI Grams - aigrams.team@gmail.com<br/>
Website - https://aigrams.herokuapp.com/

<!-- MARKDOWN LINKS & IMAGES -->
[forks-shield]: https://img.shields.io/github/forks/AIGrams/ai_grams_pm.svg?style=flat
[forks-url]: https://github.com/AIGrams/ai_grams_pm/network/members
[stars-shield]: https://img.shields.io/github/stars/AIGrams/ai_grams_pm.svg?style=flat
[stars-url]: https://github.com/AIGrams/ai_grams_pm/stargazers
[issues-shield]: https://img.shields.io/github/issues/AIGrams/ai_grams_pm.svg?style=flat
[issues-url]: https://github.com/AIGrams/ai_grams_pm/issues